Modules
- aig
- aig_
serdes - aig_sim
- check_
equivalence - cut_db
- 4-input cut database support.
- cut_
db_ cli_ defaults - Consolidated defaults for cut-db rewriting as used by CLI entrypoints.
- diverse_
samples - dslx_
stitch_ pipeline - Simple utility to stitch together pipeline stages defined in DSLX.
- gate_
builder - The
GateBuilderis a builder for aGateFn– it builds up the underlying (AIG) data structure as operations are added. - gate_
fn_ equiv_ report - gatify
- Gateification (PIR →
GateFn) and associated pre-lowering rewrites. - ir2gate_
utils - These are helper routines for the process of mapping XLS IR operations to gates.
- ir2gates
- ir_
aig_ sharing - Candidate discovery for mapping PIR node output bits to AIG node outputs.
- liberty
- liberty_
proto - mcmc_
logic - netlist
- process_
ir_ path - propose_
equiv - Functionality for proposing equivalence classes via concrete simulation.
- prove_
gate_ fn_ equiv_ common - prove_
gate_ fn_ equiv_ varisat - Validates equivalence classes proposed by
propose_equiv. - result_
proto - test_
utils - transforms
- use_
count - verilog_
version - Enumeration of HDL versions that the code generators can emit. Using a dedicated type avoids the ambiguity of passing around a bool.